@@ -83,9 +83,10 @@ option in config.  Here are the options it supports:
 """
 
 import math
-from strange_case.registry import Registry
 from strange_case.nodes.jinja import JinjaNode
 from strange_case.nodes import Processor
+from strange_case.registry import Registry
+from strange_case.configurators import configurate
 import types
 
 
@@ -216,7 +217,7 @@ def paginated_processor(config, source_path, target_path):
             page_config.setdefault('title', "%s %i" % (page_title, page_index))
             page_config.setdefault('page', page)
             page_config.setdefault('iterable', False)
-            Registry.configurate(source_path, page_config)
+            configurate(source_path, page_config)
             more_page_config = self.config.get('pages', {}).get(page_index, None)
             if more_page_config:
                 page_config.update(more_page_config)
