@@ -16,8 +16,15 @@ class JinjaNode(PageNode):
         self.files_written.append(target_path)
 
     def render(self, site=None):
+        source_path = self.source_path
+        # source_path could be an absolute path, in which case jinja2 actually
+        # gets confused.  remove the site_path from source_path so this doesn't
+        # happen.
+        if source_path[0] == '/':
+            source_path = source_path[len(self.config['project_path']):]
+
         try:
-            template = Registry.get('jinja_environment').get_template(self.source_path)
+            template = Registry.get('jinja_environment').get_template(source_path)
         except UnicodeDecodeError as e:
             e.args += "Could not process '%s' because of unicode error." % self.source_path
             raise
